@@ -18,6 +18,7 @@
 
 import copy
 import functools
+import math
 import os
 import time
 
@@ -1493,6 +1494,9 @@ class FileDiff(melddoc.MeldDoc, gnomeglade.Component):
         text = text_type(buf.get_text(start, end, False), 'utf8')
 
         source_encoding = bufdata.sourcefile.get_encoding()
+        if not source_encoding:
+            # no encoding for new blank comparison
+            source_encoding = GtkSource.Encoding.get_utf8()
         while isinstance(text, unicode):
             try:
                 encoding = source_encoding.get_charset()
@@ -1715,6 +1719,7 @@ class FileDiff(melddoc.MeldDoc, gnomeglade.Component):
                 val += (other_line-int(other_line)) * height
                 val = min(max(val, adj.get_lower()),
                           adj.get_upper() - adj.get_page_size())
+                val = math.floor(val)
                 adj.set_value(val)
 
                 # If we just changed the central bar, make it the master
